parsedatetime.parsedatetime_consts.pdtLocale_au

Package parsedatetime :: Module parsedatetime_consts :: Class pdtLocale_au |
[hide private]
[frames] | no frames]

# Class pdtLocale_au

source code

en_AU Locale constants

This class will be used to initialize Constants if PyICU is not located.

Defined as class variables are the lists and strings needed by parsedatetime to evaluate strings for Australia

Class Variables | [hide private]
`` | localeID = `'en_AU'`
`` | dateSep = `[u'-', u'/']`
`` | timeSep = `[u':']`
`` | meridian = `[u'AM', u'PM']`
`` | usesMeridian = `True`
`` | uses24 = `False`
`` | Weekdays = `[u'monday', u'tuesday', u'wednesday', u'thursday', u...`
`` | shortWeekdays = `[u'mon', u'tues', u'wed', u'thu', u'fri', u'sat', u'...`
`` | Months = `[u'january', u'february', u'march', u'april', u'may'...`
`` | shortMonths = `[u'jan', u'feb', u'mar', u'apr', u'may', u'jun', u'j...`
`` | dateFormats = `{'medium': 'dd/MM/yyyy', 'full': 'EEEE, d MMMM yyyy'...`
`` | timeFormats = `{'medium': 'h:mm:ss a', 'full': 'h:mm:ss a z', 'long...`
`` | dp_order = `[u'd', u'm', u'y']`
`` | units = `{'seconds': ['second', 'sec'], 'months': ['month', '...`
`` | re_consts = `{'timeseperator': ':', 'rangeseperator': '-', 'daysu...`
`` | modifiers = `{'ago': 1, 'eo': 0, 'from': 1, 'in a': 2, 'this': 0,...`
`` | dayoffsets = `{'tomorrow': 1, 'today': 0, 'yesterday': -1}`
`` | re_sources = `{'evening': {'hr': 18, 'mn': 0, 'sec': 0}, 'eod': {'...`

Class Variable Details | [hide private]

    ### localeID None Value:
        'en_AU'

    ### dateSep None Value:
        [u'-', u'/']

    ### timeSep None Value:
        [u':']

    ### meridian None Value:
        [u'AM', u'PM']

    ### usesMeridian None Value:
        True

    ### uses24 None Value:
        False

    ### Weekdays None Value:
        [u'monday',
         u'tuesday',
         u'wednesday',
         u'thursday',
         u'friday',
         u'saturday',
         u'sunday']

    ### shortWeekdays None Value:
        [u'mon', u'tues', u'wed', u'thu', u'fri', u'sat', u'sun']

    ### Months None Value:
        [u'january',
         u'february',
         u'march',
         u'april',
         u'may',
         u'june',
         u'july',
         u'august',
        ...

    ### shortMonths None Value:
        [u'jan', u'feb', u'mar', u'apr', u'may', u'jun', u'jul', u'aug', u'sep
        ']

    ### dateFormats None Value:
        {'full': 'EEEE, d MMMM yyyy',
         'long': 'd MMMM yyyy',
         'medium': 'dd/MM/yyyy',
         'short': 'd/MM/yy'}

    ### timeFormats None Value:
        {'full': 'h:mm:ss a z',
         'long': 'h:mm:ss a',
         'medium': 'h:mm:ss a',
         'short': 'h:mm a'}

    ### dp_order None Value:
        [u'd', u'm', u'y']

    ### units None Value:
        {'days': ['day', 'dy'],
         'hours': ['hour', 'hr'],
         'minutes': ['minute', 'min'],
         'months': ['month', 'mth'],
         'seconds': ['second', 'sec'],
         'weeks': ['week', 'wk'],
         'years': ['year', 'yr']}

    ### re_consts None Value:
        {'daysuffix': 'rd|st|nd|th',
         'meridian': 'am|pm|a.m.|p.m.|a|p',
         'now': ['now'],
         'qunits': 'h|m|s|d|w|m|y',
         'rangeseperator': '-',
         'specials': 'in|on|of|at',
         'timeseperator': ':'}

    ### modifiers None Value:
        {'after': 1,
         'ago': 1,
         'before': -1,
         'end of': 0,
         'eo': 0,
         'from': 1,
         'in a': 2,
         'last': -1,
        ...

    ### dayoffsets None Value:
        {'tomorrow': 1, 'today': 0, 'yesterday': -1}

    ### re_sources None Value:
        {'breakfast': {'hr': 8, 'mn': 0, 'sec': 0},
         'dinner': {'hr': 19, 'mn': 0, 'sec': 0},
         'eod': {'hr': 17, 'mn': 0, 'sec': 0},
         'evening': {'hr': 18, 'mn': 0, 'sec': 0},
         'lunch': {'hr': 12, 'mn': 0, 'sec': 0},
         'midnight': {'hr': 0, 'mn': 0, 'sec': 0},
         'morning': {'hr': 6, 'mn': 0, 'sec': 0},
         'night': {'hr': 21, 'mn': 0, 'sec': 0},
        ...